Learn R Programming

testequavar (version 0.1.5)

equa2vartest: Bootstrap test for equality of two (2) population variances

Description

Testing equality of two (2) population variances against the alternative that both variances are not equal.

Usage

equa2vartest(x1, x2, a, B)

Value

list consisting of a non-numeric decision whether to reject the null hypothesis or not, the significance level, the number of bootstrap samples used, and the bootstrap P-value calculated using the Euclidean distance.

Arguments

x1

first sample vector of data or observations

x2

second sample vector of data or observations

a

significance level alpha

B

number of bootstrap samples. At least 500 is recommended.

References

Cahoy, DO (2010), A Bootstrap Test For Equality Of Variances, Computational Statistics & Data Analysis, 54(10), 2306-2316. tools:::Rd_expr_doi("10.1016/j.csda.2010.04.012")

Examples

Run this code


x1=sqrt(10)*runif(8, -sqrt(3), sqrt(3) )
x2=sqrt(1)*runif(8, -sqrt(3), sqrt(3) )
equa2vartest(x1,x2,0.05, 1000)



x1=sqrt(1)*rexp(8)
x2=sqrt(1)*rexp(8)
equa2vartest(x1,x2,0.01, 1000)



Run the code above in your browser using DataLab